@@ -11,10 +11,6 @@ import requests
 import tarfile
 from bs4 import BeautifulSoup
 
-from six import string_types
-
-from collections import OrderedDict
-
 from astropy.table import Table
 from astropy.coordinates import SkyCoord, Angle
 import astropy.units as aunits
@@ -25,6 +21,7 @@ from .config import (
     ATNF_BASE_URL,
     ADS_URL,
     ATNF_TARBALL,
+    ATNF_VERSION_TARBALL,
     MSP_URL,
     PSR_ALL,
     PSR_ALL_PARS,
@@ -33,7 +30,7 @@ from .config import (
 )
 
 
-def get_catalogue(path_to_db=None, cache=True, update=False, pandas=False):
+def get_catalogue(path_to_db=None, cache=True, update=False, pandas=False, version="latest"):
     """
     This function will attempt to download and cache the entire ATNF Pulsar
     Catalogue database `tarball
@@ -58,6 +55,9 @@ def get_catalogue(path_to_db=None, cache=True, update=False, pandas=False):
         pandas (bool): if True the catalogue will be returned as a
             :class:`pandas.DataFrame` rather than the default of an
             :class:`~astropy.table.Table`.
+        version (str): the version string (without the leading "v") of the ATNF
+            catalogue version to download. This defaults to "latest" to get the
+            most up-to-date version.
 
     Returns:
         :class:`~astropy.table.Table` or :class:`~pandas.DataFrame`: a table
@@ -71,11 +71,18 @@ def get_catalogue(path_to_db=None, cache=True, update=False, pandas=False):
             if check_update():
                 clear_download_cache(ATNF_TARBALL)
 
+        if version == "latest":
+            atnftarball = ATNF_TARBALL
+        else:
+            atnftarball = ATNF_VERSION_TARBALL.format(version)
+
         # get the tarball
         try:
-            dbtarfile = download_file(ATNF_TARBALL, cache=cache)
+            dbtarfile = download_file(atnftarball, cache=cache)
         except IOError:
-            raise IOError("Problem accessing ATNF catalogue tarball")
+            raise IOError(
+                "Problem accessing ATNF catalogue tarball: {}".format(atnftarball)
+            )
 
         try:
             # open tarball
@@ -101,7 +108,7 @@ def get_catalogue(path_to_db=None, cache=True, update=False, pandas=False):
 
     # loop through lines in dbfile
     for line in dbfile.readlines():
-        if isinstance(line, string_types):
+        if isinstance(line, str):
             dataline = line.split()
         else:
             dataline = line.decode().split()  # Splits on whitespace
@@ -378,7 +385,7 @@ def get_glitch_catalogue(psr=None):
     rows = soup.table.find_all("tr")
 
     # set the table headings
-    tabledict = OrderedDict()
+    tabledict = dict()
     tabledict["NAME"] = []
     tabledict["JNAME"] = []
     tabledict["Glitch number"] = []
@@ -739,14 +746,17 @@ def get_msp_catalogue():
     """
     Download and parse Dunc Lorimer's `catalogue
     <http://astro.phys.wvu.edu/GalacticMSPs/GalacticMSPs.txt>`_ of galactic
-    millisecond pulsars. This makes use of `@astrogewgaw <https://github.com/astrogewgaw>`_'s
-    scraped version of the `table <https://github.com/astrogewgaw/galmsps>`_.
+    millisecond pulsars. This makes use of code from the now deleted `galmsps
+    <https://github.com/astrogewgaw/galmsps>`_ respository that scraped the
+    database into JSON every month, contributed by `@astrogewgaw
+    <https://github.com/astrogewgaw>`_ before deletion via `PR #88
+    <https://github.com/mattpitkin/psrqpy/pull/88>`_.
 
     Returns:
         :class:`~astropy.table.Table`: a table the MSPs.
     """
 
-    import json
+    import re
 
     # get the webpage
     try:
@@ -758,8 +768,45 @@ def get_msp_catalogue():
         warnings.warn("Count not query the MSP table.", UserWarning)
         return None
 
-    # convert from btyes to utf-8
-    tabledata = json.loads(mspt.content.decode("utf-8"))["data"]
+    numeric = (
+        lambda _: float(_)
+        if re.search(re.compile(r"^[-+]?[0-9]*[.]?[0-9]+([eE][-+]?[0-9]+)?$"), _)
+        else None
+    )
+
+    # parse the text file into a dict
+    tabledata = {
+        str(i + 1): {
+            key: conv(value)  # type: ignore
+            for (key, conv), value in zip(
+                [
+                    ("NAME", str),
+                    ("P0", numeric),
+                    ("DM", numeric),
+                    ("GL", numeric),
+                    ("GB", numeric),
+                    ("PB", numeric),
+                    ("A1", numeric),
+                    ("DISCOVERY YEAR", int),
+                    ("NOTES", str),
+                ],
+                values,
+            )
+        }
+        for i, values in enumerate(
+            [
+                [_ for _ in re.split(r"\s+", _) if _]
+                for _ in re.split(
+                    r"\n+",
+                    re.sub(
+                        re.compile(r"^([^#]*)[#](.*)$", re.MULTILINE),
+                        "",
+                        mspt.content.decode(),
+                    ).strip(),
+                )
+            ]
+        )
+    }
 
     # column names
     colnames = [
@@ -1296,7 +1343,7 @@ def condition(table, expression, exactMatch=False):
         else:
             return table[expression]
     else:
-        if not isinstance(expression, string_types):
+        if not isinstance(expression, str):
             raise TypeError("Expression must be a boolean array or a string")
         else:
             if len(expression) == 0:
